@@ -2,20 +2,17 @@
 #'
 #' @return
 #' NULL
-#' @export
-#'
-#' @rdname app
-#'
-#' @examples
-#' # Not Run
-run_gratis_app <- function() {
-  appDir <- system.file("shiny", "gratis", package = "gratis")
-  if (appDir == "") {
-    stop("Could not find example directory. Try re-installing `gratis`.", call. = FALSE)
-  }
-
-  shiny::runApp(appDir, display.mode = "normal", quiet = TRUE)
-}
+#
+# @examples
+# # Not Run
+# run_gratis_app <- function() {
+#   appDir <- system.file("shiny", "gratis", package = "gratis")
+#   if (appDir == "") {
+#     stop("Could not find example directory. Try re-installing `gratis`.", call. = FALSE)
+#   }
+# 
+#   shiny::runApp(appDir, display.mode = "normal", quiet = TRUE)
+# }
 
 #' @rdname app
 #' @export
